# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class NotificationGroupType(BaseObject):
    """
    Describes the type of notifications in a notification group
    
    """

    ID: str = Field("notificationGroupType", alias="@type")


class NotificationGroupTypeCalls(NotificationGroupType):
    """
    A group containing notifications of type notificationTypeNewCall
    
    """

    ID: str = Field("notificationGroupTypeCalls", alias="@type")

    @staticmethod
    def read(q: dict) -> NotificationGroupTypeCalls:
        return NotificationGroupTypeCalls.construct(**q)


class NotificationGroupTypeMentions(NotificationGroupType):
    """
    A group containing notifications of type notificationTypeNewMessage and notificationTypeNewPushMessage with unread mentions of the current user, replies to their messages, or a pinned message
    
    """

    ID: str = Field("notificationGroupTypeMentions", alias="@type")

    @staticmethod
    def read(q: dict) -> NotificationGroupTypeMentions:
        return NotificationGroupTypeMentions.construct(**q)


class NotificationGroupTypeMessages(NotificationGroupType):
    """
    A group containing notifications of type notificationTypeNewMessage and notificationTypeNewPushMessage with ordinary unread messages
    
    """

    ID: str = Field("notificationGroupTypeMessages", alias="@type")

    @staticmethod
    def read(q: dict) -> NotificationGroupTypeMessages:
        return NotificationGroupTypeMessages.construct(**q)


class NotificationGroupTypeSecretChat(NotificationGroupType):
    """
    A group containing a notification of type notificationTypeNewSecretChat
    
    """

    ID: str = Field("notificationGroupTypeSecretChat", alias="@type")

    @staticmethod
    def read(q: dict) -> NotificationGroupTypeSecretChat:
        return NotificationGroupTypeSecretChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class LogVerbosityLevel(BaseObject):
    """
    Contains a TDLib internal log verbosity level
    
    Params:
        verbosity_level (:class:`int`)
            Log verbosity level
        
    """

    ID: str = Field("logVerbosityLevel", alias="@type")
    verbosity_level: int

    @staticmethod
    def read(q: dict) -> LogVerbosityLevel:
        return LogVerbosityLevel.construct(**q)



__version__ = "0.8.2"

from .client import (
    Client,
    ClientProxySettings,
    ClientProxyType,
)
from .filters import (
    AllFilter,
    AnimationFilter,
    AudioFilter,
    BaseFilter,
    BaseObjectFilter,
    BotCommandFilter,
    ContactFilter,
    DiceFilter,
    DocumentFilter,
    FilterCallable,
    Filters,
    GameFilter,
    InvertedFilter,
    InvoiceFilter,
    LocationFilter,
    MergedFilter,
    MessageFilter,
    PhotoFilter,
    PollFilter,
    RegexFilter,
    StickerFilter,
    TextFilter,
    UnsupportedFilter,
    VenueFilter,
    VideoFilter,
    VideoNoteFilter,
    VoiceNoteFilter,
    XORFilter,
)
from .handlers import (
    Handler,
    HandlerCallable,
)
from .middlewares import MiddlewareCallable
from .tdjson import (
    TDJson,
    TDLibLogVerbosity,
)
from .utils import PendingRequest



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .input_file import InputFile
from ..base_object import BaseObject


class InputPersonalDocument(BaseObject):
    """
    A personal document to be saved to Telegram Passport
    
    Params:
        files (:obj:`list[InputFile]`)
            List of files containing the pages of the document
        
        translation (:obj:`list[InputFile]`)
            List of files containing a certified English translation of the document
        
    """

    ID: str = Field("inputPersonalDocument", alias="@type")
    files: list[InputFile]
    translation: list[InputFile]

    @staticmethod
    def read(q: dict) -> InputPersonalDocument:
        return InputPersonalDocument.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class LanguagePackInfo(BaseObject):
    """
    Contains information about a language pack
    
    Params:
        id (:class:`str`)
            Unique language pack identifier
        
        base_language_pack_id (:class:`str`)
            Identifier of a base language pack; may be empty. If a string is missed in the language pack, then it should be fetched from base language pack. Unsupported in custom language packs
        
        name (:class:`str`)
            Language name
        
        native_name (:class:`str`)
            Name of the language in that language
        
        plural_code (:class:`str`)
            A language code to be used to apply plural forms. See https://www.unicode.org/cldr/charts/latest/supplemental/language_plural_rules.html for more info
        
        is_official (:class:`bool`)
            True, if the language pack is official
        
        is_rtl (:class:`bool`)
            True, if the language pack strings are RTL
        
        is_beta (:class:`bool`)
            True, if the language pack is a beta language pack
        
        is_installed (:class:`bool`)
            True, if the language pack is installed by the current user
        
        total_string_count (:class:`int`)
            Total number of non-deleted strings from the language pack
        
        translated_string_count (:class:`int`)
            Total number of translated strings from the language pack
        
        local_string_count (:class:`int`)
            Total number of non-deleted strings from the language pack available locally
        
        translation_url (:class:`str`)
            Link to language translation interface; empty for custom local language packs
        
    """

    ID: str = Field("languagePackInfo", alias="@type")
    id: str
    base_language_pack_id: str
    name: str
    native_name: str
    plural_code: str
    is_official: bool
    is_rtl: bool
    is_beta: bool
    is_installed: bool
    total_string_count: int
    translated_string_count: int
    local_string_count: int
    translation_url: str

    @staticmethod
    def read(q: dict) -> LanguagePackInfo:
        return LanguagePackInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SearchCallMessages(BaseObject):
    """
    Searches for call messages. Returns the results in reverse chronological order (i. e., in order of decreasing message_id). For optimal performance the number of returned messages is chosen by the library
    
    Params:
        from_message_id (:class:`int`)
            Identifier of the message from which to search; use 0 to get results from the last message
        
        limit (:class:`int`)
            The maximum number of messages to be returned; up to 100. Fewer messages may be returned than specified by the limit, even if the end of the message history has not been reached
        
        only_missed (:class:`bool`)
            If true, returns only messages with missed calls
        
    """

    ID: str = Field("searchCallMessages", alias="@type")
    from_message_id: int
    limit: int
    only_missed: bool

    @staticmethod
    def read(q: dict) -> SearchCallMessages:
        return SearchCallMessages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ImportedContacts(BaseObject):
    """
    Represents the result of an ImportContacts request
    
    Params:
        user_ids (:obj:`list[int]`)
            User identifiers of the imported contacts in the same order as they were specified in the request; 0 if the contact is not yet a registered user
        
        importer_count (:obj:`list[int]`)
            The number of users that imported the corresponding contact; 0 for already registered users or if unavailable
        
    """

    ID: str = Field("importedContacts", alias="@type")
    user_ids: list[int]
    importer_count: list[int]

    @staticmethod
    def read(q: dict) -> ImportedContacts:
        return ImportedContacts.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .call_state import CallState
from ..base_object import BaseObject


class Call(BaseObject):
    """
    Describes a call
    
    Params:
        id (:class:`int`)
            Call identifier, not persistent
        
        user_id (:class:`int`)
            Peer user identifier
        
        is_outgoing (:class:`bool`)
            True, if the call is outgoing
        
        is_video (:class:`bool`)
            True, if the call is a video call
        
        state (:class:`CallState`)
            Call state
        
    """

    ID: str = Field("call", alias="@type")
    id: int
    user_id: int
    is_outgoing: bool
    is_video: bool
    state: CallState

    @staticmethod
    def read(q: dict) -> Call:
        return Call.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class AddChatMembers(BaseObject):
    """
    Adds multiple new members to a chat. Currently this method is only available for supergroups and channels. This method can't be used to join a chat. Members can't be added to a channel if it has more than 200 members
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        user_ids (:obj:`list[int]`)
            Identifiers of the users to be added to the chat. The maximum number of added users is 20 for supergroups and 100 for channels
        
    """

    ID: str = Field("addChatMembers", alias="@type")
    chat_id: int
    user_ids: list[int]

    @staticmethod
    def read(q: dict) -> AddChatMembers:
        return AddChatMembers.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .chat_event import ChatEvent
from ..base_object import BaseObject


class ChatEvents(BaseObject):
    """
    Contains a list of chat events
    
    Params:
        events (:obj:`list[ChatEvent]`)
            List of events
        
    """

    ID: str = Field("chatEvents", alias="@type")
    events: list[ChatEvent]

    @staticmethod
    def read(q: dict) -> ChatEvents:
        return ChatEvents.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import Contact


class AddContact(BaseObject):
    """
    Adds a user to the contact list or edits an existing contact by their user identifier
    
    Params:
        contact (:class:`Contact`)
            The contact to add or edit; phone number can be empty and needs to be specified only if known, vCard is ignored
        
        share_phone_number (:class:`bool`)
            True, if the new contact needs to be allowed to see current user's phone number. A corresponding rule to userPrivacySettingShowPhoneNumber will be added if needed. Use the field UserFullInfo.need_phone_number_privacy_exception to check whether the current user needs to be asked to share their phone number
        
    """

    ID: str = Field("addContact", alias="@type")
    contact: Contact
    share_phone_number: bool

    @staticmethod
    def read(q: dict) -> AddContact:
        return AddContact.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .sticker import Sticker
from ..base_object import BaseObject


class DiceStickers(BaseObject):
    """
    Contains animated stickers which should be used for dice animation rendering
    
    """

    ID: str = Field("diceStickers", alias="@type")


class DiceStickersRegular(DiceStickers):
    """
    A regular animated sticker
    
    Params:
        sticker (:class:`Sticker`)
            The animated sticker with the dice animation
        
    """

    ID: str = Field("diceStickersRegular", alias="@type")
    sticker: Sticker

    @staticmethod
    def read(q: dict) -> DiceStickersRegular:
        return DiceStickersRegular.construct(**q)


class DiceStickersSlotMachine(DiceStickers):
    """
    Animated stickers to be combined into a slot machine
    
    Params:
        background (:class:`Sticker`)
            The animated sticker with the slot machine background. The background animation must start playing after all reel animations finish
        
        lever (:class:`Sticker`)
            The animated sticker with the lever animation. The lever animation must play once in the initial dice state
        
        left_reel (:class:`Sticker`)
            The animated sticker with the left reel
        
        center_reel (:class:`Sticker`)
            The animated sticker with the center reel
        
        right_reel (:class:`Sticker`)
            The animated sticker with the right reel
        
    """

    ID: str = Field("diceStickersSlotMachine", alias="@type")
    background: Sticker
    lever: Sticker
    left_reel: Sticker
    center_reel: Sticker
    right_reel: Sticker

    @staticmethod
    def read(q: dict) -> DiceStickersSlotMachine:
        return DiceStickersSlotMachine.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetChatMessageByDate(BaseObject):
    """
    Returns the last message sent in a chat no later than the specified date
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        date (:class:`int`)
            Point in time (Unix timestamp) relative to which to search for messages
        
    """

    ID: str = Field("getChatMessageByDate", alias="@type")
    chat_id: int
    date: int

    @staticmethod
    def read(q: dict) -> GetChatMessageByDate:
        return GetChatMessageByDate.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .inline_keyboard_button import InlineKeyboardButton
from .keyboard_button import KeyboardButton
from ..base_object import BaseObject


class ReplyMarkup(BaseObject):
    """
    Contains a description of a custom keyboard and actions that can be done with it to quickly reply to bots
    
    """

    ID: str = Field("replyMarkup", alias="@type")


class ReplyMarkupForceReply(ReplyMarkup):
    """
    Instructs application to force a reply to this message
    
    Params:
        is_personal (:class:`bool`)
            True, if a forced reply must automatically be shown to the current user. For outgoing messages, specify true to show the forced reply only for the mentioned users and for the target user of a reply
        
        input_field_placeholder (:class:`str`)
            If non-empty, the placeholder to be shown in the input field when the reply is active; 0-64 characters
        
    """

    ID: str = Field("replyMarkupForceReply", alias="@type")
    is_personal: bool
    input_field_placeholder: typing.Optional[str] = Field(None, max_length=64)

    @staticmethod
    def read(q: dict) -> ReplyMarkupForceReply:
        return ReplyMarkupForceReply.construct(**q)


class ReplyMarkupInlineKeyboard(ReplyMarkup):
    """
    Contains an inline keyboard layout
    
    Params:
        rows (:obj:`list[list[InlineKeyboardButton]]`)
            A list of rows of inline keyboard buttons
        
    """

    ID: str = Field("replyMarkupInlineKeyboard", alias="@type")
    rows: list[list[InlineKeyboardButton]]

    @staticmethod
    def read(q: dict) -> ReplyMarkupInlineKeyboard:
        return ReplyMarkupInlineKeyboard.construct(**q)


class ReplyMarkupRemoveKeyboard(ReplyMarkup):
    """
    Instructs application to remove the keyboard once this message has been received. This kind of keyboard can't be received in an incoming message; instead, UpdateChatReplyMarkup with message_id == 0 will be sent
    
    Params:
        is_personal (:class:`bool`)
            True, if the keyboard is removed only for the mentioned users or the target user of a reply
        
    """

    ID: str = Field("replyMarkupRemoveKeyboard", alias="@type")
    is_personal: bool

    @staticmethod
    def read(q: dict) -> ReplyMarkupRemoveKeyboard:
        return ReplyMarkupRemoveKeyboard.construct(**q)


class ReplyMarkupShowKeyboard(ReplyMarkup):
    """
    Contains a custom keyboard layout to quickly reply to bots
    
    Params:
        rows (:obj:`list[list[KeyboardButton]]`)
            A list of rows of bot keyboard buttons
        
        resize_keyboard (:class:`bool`)
            True, if the application needs to resize the keyboard vertically
        
        one_time (:class:`bool`)
            True, if the application needs to hide the keyboard after use
        
        is_personal (:class:`bool`)
            True, if the keyboard must automatically be shown to the current user. For outgoing messages, specify true to show the keyboard only for the mentioned users and for the target user of a reply
        
        input_field_placeholder (:class:`str`)
            If non-empty, the placeholder to be shown in the input field when the keyboard is active; 0-64 characters
        
    """

    ID: str = Field("replyMarkupShowKeyboard", alias="@type")
    rows: list[list[KeyboardButton]]
    resize_keyboard: bool
    one_time: bool
    is_personal: bool
    input_field_placeholder: typing.Optional[str] = Field(None, max_length=64)

    @staticmethod
    def read(q: dict) -> ReplyMarkupShowKeyboard:
        return ReplyMarkupShowKeyboard.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .file import File
from ..base_object import BaseObject


class PhotoSize(BaseObject):
    """
    Describes an image in JPEG format
    
    Params:
        type_ (:class:`str`)
            Image type (see https://core.telegram.org/constructor/photoSize)
        
        photo (:class:`File`)
            Information about the image file
        
        width (:class:`int`)
            Image width
        
        height (:class:`int`)
            Image height
        
        progressive_sizes (:obj:`list[int]`)
            Sizes of progressive JPEG file prefixes, which can be used to preliminarily show the image
        
    """

    ID: str = Field("photoSize", alias="@type")
    type_: str = Field(..., alias='type')
    photo: File
    width: int
    height: int
    progressive_sizes: list[int]

    @staticmethod
    def read(q: dict) -> PhotoSize:
        return PhotoSize.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CancelPasswordReset(BaseObject):
    """
    Cancels reset of 2-step verification password. The method can be called if passwordState.pending_reset_date > 0
    
    """

    ID: str = Field("cancelPasswordReset", alias="@type")

    @staticmethod
    def read(q: dict) -> CancelPasswordReset:
        return CancelPasswordReset.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class AnswerCallbackQuery(BaseObject):
    """
    Sets the result of a callback query; for bots only
    
    Params:
        callback_query_id (:class:`int`)
            Identifier of the callback query
        
        text (:class:`str`)
            Text of the answer
        
        show_alert (:class:`bool`)
            If true, an alert should be shown to the user instead of a toast notification
        
        url (:class:`str`)
            URL to be opened
        
        cache_time (:class:`int`)
            Time during which the result of the query can be cached, in seconds
        
    """

    ID: str = Field("answerCallbackQuery", alias="@type")
    callback_query_id: int
    text: str
    show_alert: bool
    url: str
    cache_time: int

    @staticmethod
    def read(q: dict) -> AnswerCallbackQuery:
        return AnswerCallbackQuery.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class TestUseUpdate(BaseObject):
    """
    Does nothing and ensures that the Update object is used; for testing only. This is an offline method. Can be called before authorization
    
    """

    ID: str = Field("testUseUpdate", alias="@type")

    @staticmethod
    def read(q: dict) -> TestUseUpdate:
        return TestUseUpdate.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputSticker


class AddStickerToSet(BaseObject):
    """
    Adds a new sticker to a set; for bots only. Returns the sticker set
    
    Params:
        user_id (:class:`int`)
            Sticker set owner
        
        name (:class:`str`)
            Sticker set name
        
        sticker (:class:`InputSticker`)
            Sticker to add to the set
        
    """

    ID: str = Field("addStickerToSet", alias="@type")
    user_id: int
    name: str
    sticker: InputSticker

    @staticmethod
    def read(q: dict) -> AddStickerToSet:
        return AddStickerToSet.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ResendMessages(BaseObject):
    """
    Resends messages which failed to send. Can be called only for messages for which messageSendingStateFailed.can_retry is true and after specified in messageSendingStateFailed.retry_after time passed. If a message is re-sent, the corresponding failed to send message is deleted. Returns the sent messages in the same order as the message identifiers passed in message_ids. If a message can't be re-sent, null will be returned instead of the message
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat to send messages
        
        message_ids (:obj:`list[int]`)
            Identifiers of the messages to resend. Message identifiers must be in a strictly increasing order
        
    """

    ID: str = Field("resendMessages", alias="@type")
    chat_id: int
    message_ids: list[int]

    @staticmethod
    def read(q: dict) -> ResendMessages:
        return ResendMessages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .proxy_type import ProxyType
from ..base_object import BaseObject


class Proxy(BaseObject):
    """
    Contains information about a proxy server
    
    Params:
        id (:class:`int`)
            Unique identifier of the proxy
        
        server (:class:`str`)
            Proxy server IP address
        
        port (:class:`int`)
            Proxy server port
        
        last_used_date (:class:`int`)
            Point in time (Unix timestamp) when the proxy was last used; 0 if never
        
        is_enabled (:class:`bool`)
            True, if the proxy is enabled now
        
        type_ (:class:`ProxyType`)
            Type of the proxy
        
    """

    ID: str = Field("proxy", alias="@type")
    id: int
    server: str
    port: int
    last_used_date: int
    is_enabled: bool
    type_: ProxyType = Field(..., alias='type')

    @staticmethod
    def read(q: dict) -> Proxy:
        return Proxy.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .chat_member_status import ChatMemberStatus
from .message_sender import MessageSender
from ..base_object import BaseObject


class ChatMember(BaseObject):
    """
    Information about a user or a chat as a member of another chat
    
    Params:
        member_id (:class:`MessageSender`)
            Identifier of the chat member. Currently, other chats can be only Left or Banned. Only supergroups and channels can have other chats as Left or Banned members and these chats must be supergroups or channels
        
        inviter_user_id (:class:`int`)
            Identifier of a user that invited/promoted/banned this member in the chat; 0 if unknown
        
        joined_chat_date (:class:`int`)
            Point in time (Unix timestamp) when the user joined the chat
        
        status (:class:`ChatMemberStatus`)
            Status of the member in the chat
        
    """

    ID: str = Field("chatMember", alias="@type")
    member_id: MessageSender
    inviter_user_id: int
    joined_chat_date: int
    status: ChatMemberStatus

    @staticmethod
    def read(q: dict) -> ChatMember:
        return ChatMember.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SendCallDebugInformation(BaseObject):
    """
    Sends debug information for a call
    
    Params:
        call_id (:class:`int`)
            Call identifier
        
        debug_information (:class:`str`)
            Debug information in application-specific format
        
    """

    ID: str = Field("sendCallDebugInformation", alias="@type")
    call_id: int
    debug_information: str

    @staticmethod
    def read(q: dict) -> SendCallDebugInformation:
        return SendCallDebugInformation.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetInstalledStickerSets(BaseObject):
    """
    Returns a list of installed sticker sets
    
    Params:
        is_masks (:class:`bool`)
            Pass true to return mask sticker sets; pass false to return ordinary sticker sets
        
    """

    ID: str = Field("getInstalledStickerSets", alias="@type")
    is_masks: bool

    @staticmethod
    def read(q: dict) -> GetInstalledStickerSets:
        return GetInstalledStickerSets.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetCallbackQueryMessage(BaseObject):
    """
    Returns information about a message with the callback button that originated a callback query; for bots only
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat the message belongs to
        
        message_id (:class:`int`)
            Message identifier
        
        callback_query_id (:class:`int`)
            Identifier of the callback query
        
    """

    ID: str = Field("getCallbackQueryMessage", alias="@type")
    chat_id: int
    message_id: int
    callback_query_id: int

    @staticmethod
    def read(q: dict) -> GetCallbackQueryMessage:
        return GetCallbackQueryMessage.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import CallbackQueryPayload


class GetCallbackQueryAnswer(BaseObject):
    """
    Sends a callback query to a bot and returns an answer. Returns an error with code 502 if the bot fails to answer the query before the query timeout expires
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat with the message
        
        message_id (:class:`int`)
            Identifier of the message from which the query originated
        
        payload (:class:`CallbackQueryPayload`)
            Query payload
        
    """

    ID: str = Field("getCallbackQueryAnswer", alias="@type")
    chat_id: int
    message_id: int
    payload: CallbackQueryPayload

    @staticmethod
    def read(q: dict) -> GetCallbackQueryAnswer:
        return GetCallbackQueryAnswer.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class DeleteMessages(BaseObject):
    """
    Deletes messages
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        message_ids (:obj:`list[int]`)
            Identifiers of the messages to be deleted
        
        revoke (:class:`bool`)
            Pass true to try to delete messages for all chat members. Always true for supergroups, channels and secret chats
        
    """

    ID: str = Field("deleteMessages", alias="@type")
    chat_id: int
    message_ids: list[int]
    revoke: bool

    @staticmethod
    def read(q: dict) -> DeleteMessages:
        return DeleteMessages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import Location


class GetInlineQueryResults(BaseObject):
    """
    Sends an inline query to a bot and returns its results. Returns an error with code 502 if the bot fails to answer the query before the query timeout expires
    
    Params:
        bot_user_id (:class:`int`)
            The identifier of the target bot
        
        chat_id (:class:`int`)
            Identifier of the chat where the query was sent
        
        user_location (:class:`Location`)
            Location of the user, only if needed
        
        query (:class:`str`)
            Text of the query
        
        offset (:class:`str`)
            Offset of the first entry to return
        
    """

    ID: str = Field("getInlineQueryResults", alias="@type")
    bot_user_id: int
    chat_id: int
    user_location: Location
    query: str
    offset: str

    @staticmethod
    def read(q: dict) -> GetInlineQueryResults:
        return GetInlineQueryResults.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import Error


class TestReturnError(BaseObject):
    """
    Returns the specified error and ensures that the Error object is used; for testing only. Can be called synchronously
    
    Params:
        error (:class:`Error`)
            The error to be returned
        
    """

    ID: str = Field("testReturnError", alias="@type")
    error: Error

    @staticmethod
    def read(q: dict) -> TestReturnError:
        return TestReturnError.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .chat_member import ChatMember
from ..base_object import BaseObject


class ChatMembers(BaseObject):
    """
    Contains a list of chat members
    
    Params:
        total_count (:class:`int`)
            Approximate total count of chat members found
        
        members (:obj:`list[ChatMember]`)
            A list of chat members
        
    """

    ID: str = Field("chatMembers", alias="@type")
    total_count: int
    members: list[ChatMember]

    @staticmethod
    def read(q: dict) -> ChatMembers:
        return ChatMembers.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .secret_chat_state import SecretChatState
from ..base_object import BaseObject


class SecretChat(BaseObject):
    """
    Represents a secret chat
    
    Params:
        id (:class:`int`)
            Secret chat identifier
        
        user_id (:class:`int`)
            Identifier of the chat partner
        
        state (:class:`SecretChatState`)
            State of the secret chat
        
        is_outbound (:class:`bool`)
            True, if the chat was created by the current user; otherwise false
        
        key_hash (:class:`str`)
            Hash of the currently used key for comparison with the hash of the chat partner's key. This is a string of 36 little-endian bytes, which must be split into groups of 2 bits, each denoting a pixel of one of 4 colors FFFFFF, D5E6F3, 2D5775, and 2F99C9. The pixels must be used to make a 12x12 square image filled from left to right, top to bottom. Alternatively, the first 32 bytes of the hash can be converted to the hexadecimal format and printed as 32 2-digit hex numbers
        
        layer (:class:`int`)
            Secret chat layer; determines features supported by the chat partner's application. Nested text entities and underline and strikethrough entities are supported if the layer >= 101
        
    """

    ID: str = Field("secretChat", alias="@type")
    id: int
    user_id: int
    state: SecretChatState
    is_outbound: bool
    key_hash: str
    layer: int

    @staticmethod
    def read(q: dict) -> SecretChat:
        return SecretChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class PaymentFormTheme(BaseObject):
    """
    Theme colors for a payment form
    
    Params:
        background_color (:class:`int`)
            A color of the payment form background in the RGB24 format
        
        text_color (:class:`int`)
            A color of text in the RGB24 format
        
        hint_color (:class:`int`)
            A color of hints in the RGB24 format
        
        link_color (:class:`int`)
            A color of links in the RGB24 format
        
        button_color (:class:`int`)
            A color of thebuttons in the RGB24 format
        
        button_text_color (:class:`int`)
            A color of text on the buttons in the RGB24 format
        
    """

    ID: str = Field("paymentFormTheme", alias="@type")
    background_color: int
    text_color: int
    hint_color: int
    link_color: int
    button_color: int
    button_text_color: int

    @staticmethod
    def read(q: dict) -> PaymentFormTheme:
        return PaymentFormTheme.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetPushReceiverId(BaseObject):
    """
    Returns a globally unique push notification subscription identifier for identification of an account, which has received a push notification. Can be called synchronously
    
    Params:
        payload (:class:`str`)
            JSON-encoded push notification payload
        
    """

    ID: str = Field("getPushReceiverId", alias="@type")
    payload: str

    @staticmethod
    def read(q: dict) -> GetPushReceiverId:
        return GetPushReceiverId.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ChatInviteLinkMember


class GetChatInviteLinkMembers(BaseObject):
    """
    Returns chat members joined a chat by an invite link. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        invite_link (:class:`str`)
            Invite link for which to return chat members
        
        offset_member (:class:`ChatInviteLinkMember`)
            A chat member from which to return next chat members; use null to get results from the beginning
        
        limit (:class:`int`)
            The maximum number of chat members to return
        
    """

    ID: str = Field("getChatInviteLinkMembers", alias="@type")
    chat_id: int
    invite_link: str
    offset_member: ChatInviteLinkMember
    limit: int

    @staticmethod
    def read(q: dict) -> GetChatInviteLinkMembers:
        return GetChatInviteLinkMembers.construct(**q)



import re
import typing
import urllib.request

from .entities import (
    Constructor,
    ConstructorShort,
    Method,
    Parameter,
)
from .utils import upper_first

DEFAULT_TD_API_SCHEME_URL = "https://raw.githubusercontent.com/tdlib/td/master/td/generate/scheme/td_api.tl"


class TDApiParser:
    @staticmethod
    def parse() -> list[typing.Union[Constructor, Method]]:
        abstract_class_docs_regex = re.compile(r"^//@class (?P<name>[^@]*) @description (?P<description>.*)$")
        description_regex = re.compile(r"^//@description (?P<description>.*)$")
        parameter_description_regex = re.compile(r"^//@(?P<name>.*?) (?P<description>.*)$")
        entity_regex = re.compile(r'^(?P<name>\w+)\s(?P<args>.*)=\s(?P<return_type>\w+);$')
        args_regex = re.compile(r"(?P<name>\w+):(?P<type>[\w<>]+)")
        param_length_constraint = re.compile(r"(?P<min_length>\d+)-(?P<max_length>\d+) characters")
        nullability_constraint = re.compile(r".*may be null.*")

        scheme = urllib.request.urlopen(DEFAULT_TD_API_SCHEME_URL).read().decode('utf-8')

        # Some cleaning for better parsing
        inline_parameter_regex = re.compile(r'(?!(@description|@class))(@\w+)')
        empty_slashes_regex = re.compile(r'\n//\s*$', re.MULTILINE)

        scheme = scheme.replace('\n//-', ' ')
        scheme = inline_parameter_regex.sub(r'\n//\2', scheme)
        scheme = scheme.replace('////', '//')
        scheme = empty_slashes_regex.sub('', scheme)

        methods = {}
        constructors = {}
        is_functions_section = False
        current_entity_description: str = ""
        current_entity_params_descriptions: dict[str, str] = {}

        for line in [line.strip() for line in scheme.splitlines()[14:] if len(line) > 0]:
            # After line '---functions---' only methods are described
            if line == '---functions---':
                is_functions_section = True
                continue

            abstract_class_match = abstract_class_docs_regex.match(line)

            # Abstract classes presented as
            # //@class <ClassName> @description <description>
            if bool(abstract_class_match):
                class_name = upper_first(abstract_class_match.group('name'))
                class_description = abstract_class_match.group('description')
                constructors[class_name] = Constructor(
                    name=class_name,
                    doc=class_description,
                    is_abstract=True
                )
                continue

            description_match = description_regex.match(line)

            if bool(description_match):
                current_entity_description = description_match.group('description')
                continue

            parameter_description_match = parameter_description_regex.match(line)

            if bool(parameter_description_match):
                param_name = parameter_description_match.group('name')
                param_description = parameter_description_match.group('description')
                current_entity_params_descriptions[param_name] = param_description
                continue

            entity_match = entity_regex.match(line)

            if bool(entity_match):
                entity_name = upper_first(entity_match.group('name'))
                entity_return_type = upper_first(entity_match.group('return_type'))
                entity_uf_return_type = upper_first(entity_return_type)
                entity_parameters: list[Parameter] = []

                for arg_name, arg_type in args_regex.findall(entity_match.group('args')):
                    if arg_name in ['description', 'class']:
                        arg_name = f'param_{arg_name}'

                    arg_description = current_entity_params_descriptions.get(arg_name)
                    arg_nullable = False
                    arg_min_length = None
                    arg_max_length = None

                    if ";" in arg_description:
                        # Parsing parameter constraints
                        # https://github.com/tdlib/td/issues/1016#issuecomment-618959102
                        for c in arg_description.split(";"):
                            c = c.strip()

                            if nullability_constraint.match(c):
                                arg_nullable = True

                            param_length_constraint_match = param_length_constraint.match(c)

                            if bool(param_length_constraint_match):
                                arg_min_length = int(param_length_constraint_match.group('min_length'))

                                if arg_min_length == 0:
                                    arg_nullable = True

                                arg_max_length = int(param_length_constraint_match.group('max_length'))

                    entity_parameters.append(
                        Parameter(
                            name=arg_name,
                            type=arg_type,
                            doc=arg_description,
                            nullable=arg_nullable,
                            min_length=arg_min_length,
                            max_length=arg_max_length,
                        )
                    )

                if is_functions_section:
                    methods[entity_name] = Method(
                        name=entity_name,
                        doc=current_entity_description,
                        parameters=entity_parameters,
                        return_type=(
                            constructors[entity_uf_return_type]
                            if entity_uf_return_type in constructors
                            else entity_return_type
                        )
                    )
                else:
                    if entity_uf_return_type in constructors:
                        parent = constructors[entity_uf_return_type]
                        entity = Constructor(
                            name=entity_name,
                            doc=current_entity_description,
                            parameters=entity_parameters,
                            parent_class=ConstructorShort(
                                name=parent.name,
                                doc=parent.doc,
                                parameters=parent.parameters,
                                is_abstract=parent.is_abstract
                            ),
                        )
                        parent.subclasses.append(entity)
                    else:
                        constructors[entity_name] = Constructor(
                            name=entity_name,
                            doc=current_entity_description,
                            parameters=entity_parameters,
                        )

                current_entity_params_descriptions = {}
                current_entity_description = ""
                continue

            raise RuntimeError('Something goes wrong!')

        # Separately process cross-dependencies to avoid circular import error
        cross_deps: dict[str, set[str]] = {}

        for constructor in sorted(constructors.values(), key=lambda x: x.name):
            for parameter in constructor.parameters:
                parameter_constructor = constructors.get(parameter.import_type)

                # Skip core types
                if not bool(parameter_constructor):
                    continue

                # Skip subclasses as they will be checked above in parent class processing
                if bool(parameter_constructor.parent_class):
                    continue

                # Check parameters of constructor parameters
                for p in parameter_constructor.parameters:
                    if p.import_type == constructor.name:
                        if parameter.import_type not in cross_deps:
                            cross_deps[constructor.name] = set()

                        cross_deps[constructor.name].add(constructor.name)

                # Check parameter constructor subclasses' parameters
                for subclass in parameter_constructor.subclasses:
                    for subclass_parameter in subclass.parameters:
                        if subclass_parameter.import_type == constructor.name:
                            if parameter.import_type not in cross_deps:
                                cross_deps[parameter.import_type] = set()

                            cross_deps[parameter.import_type].add(constructor.name)

        for constructor_name, cross_deps_constructors_names in cross_deps.items():
            for name in cross_deps_constructors_names:
                dep_constructor = constructors.pop(name)
                constructors[constructor_name].cross_deps.append(dep_constructor)

        methods_list: list[Method] = list(methods.values())
        constructors_list: list[Constructor] = list(constructors.values())

        # Sorting subclasses and cross_deps lists
        for constructor in constructors_list:
            constructor.subclasses.sort(key=lambda x: x.name)
            constructor.cross_deps.sort(key=lambda x: x.name)

        return list(sorted([*methods_list, *constructors_list], key=lambda x: x.name))



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .notification import Notification
from .notification_group_type import NotificationGroupType
from ..base_object import BaseObject


class NotificationGroup(BaseObject):
    """
    Describes a group of notifications
    
    Params:
        id (:class:`int`)
            Unique persistent auto-incremented from 1 identifier of the notification group
        
        type_ (:class:`NotificationGroupType`)
            Type of the group
        
        chat_id (:class:`int`)
            Identifier of a chat to which all notifications in the group belong
        
        total_count (:class:`int`)
            Total number of active notifications in the group
        
        notifications (:obj:`list[Notification]`)
            The list of active notifications
        
    """

    ID: str = Field("notificationGroup", alias="@type")
    id: int
    type_: NotificationGroupType = Field(..., alias='type')
    chat_id: int
    total_count: int
    notifications: list[Notification]

    @staticmethod
    def read(q: dict) -> NotificationGroup:
        return NotificationGroup.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .location import Location
from ..base_object import BaseObject


class Venue(BaseObject):
    """
    Describes a venue
    
    Params:
        location (:class:`Location`)
            Venue location; as defined by the sender
        
        title (:class:`str`)
            Venue name; as defined by the sender
        
        address (:class:`str`)
            Venue address; as defined by the sender
        
        provider (:class:`str`)
            Provider of the venue database; as defined by the sender. Currently only "foursquare" and "gplaces" (Google Places) need to be supported
        
        id (:class:`str`)
            Identifier of the venue in the provider database; as defined by the sender
        
        type_ (:class:`str`)
            Type of the venue in the provider database; as defined by the sender
        
    """

    ID: str = Field("venue", alias="@type")
    location: Location
    title: str
    address: str
    provider: str
    id: str
    type_: str = Field(..., alias='type')

    @staticmethod
    def read(q: dict) -> Venue:
        return Venue.construct(**q)



class AioTDLibError(Exception):
    """This is the base exception class for all TDLib API related errors."""
    code: int = None
    message: str = None

    def __init__(self, code: int, message: str):
        super().__init__(message)
        self.code = code
        self.message = message

    def __str__(self) -> str:
        return f"[Error {self.code}] {self.message}"


class BadRequest(AioTDLibError):
    def __init__(self, message: str):
        super(BadRequest, self).__init__(400, message)


class Unauthorized(AioTDLibError):
    def __init__(self, message: str):
        super(Unauthorized, self).__init__(401, message)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class OptionValue(BaseObject):
    """
    Represents the value of an option
    
    """

    ID: str = Field("optionValue", alias="@type")


class OptionValueBoolean(OptionValue):
    """
    Represents a boolean option
    
    Params:
        value (:class:`bool`)
            The value of the option
        
    """

    ID: str = Field("optionValueBoolean", alias="@type")
    value: bool

    @staticmethod
    def read(q: dict) -> OptionValueBoolean:
        return OptionValueBoolean.construct(**q)


class OptionValueEmpty(OptionValue):
    """
    Represents an unknown option or an option which has a default value
    
    """

    ID: str = Field("optionValueEmpty", alias="@type")

    @staticmethod
    def read(q: dict) -> OptionValueEmpty:
        return OptionValueEmpty.construct(**q)


class OptionValueInteger(OptionValue):
    """
    Represents an integer option
    
    Params:
        value (:class:`int`)
            The value of the option
        
    """

    ID: str = Field("optionValueInteger", alias="@type")
    value: int

    @staticmethod
    def read(q: dict) -> OptionValueInteger:
        return OptionValueInteger.construct(**q)


class OptionValueString(OptionValue):
    """
    Represents a string option
    
    Params:
        value (:class:`str`)
            The value of the option
        
    """

    ID: str = Field("optionValueString", alias="@type")
    value: str

    @staticmethod
    def read(q: dict) -> OptionValueString:
        return OptionValueString.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetPassportAuthorizationForm(BaseObject):
    """
    Returns a Telegram Passport authorization form for sharing data with a service
    
    Params:
        bot_user_id (:class:`int`)
            User identifier of the service's bot
        
        scope (:class:`str`)
            Telegram Passport element types requested by the service
        
        public_key (:class:`str`)
            Service's public key
        
        nonce (:class:`str`)
            Unique request identifier provided by the service
        
    """

    ID: str = Field("getPassportAuthorizationForm", alias="@type")
    bot_user_id: int
    scope: str
    public_key: str
    nonce: str

    @staticmethod
    def read(q: dict) -> GetPassportAuthorizationForm:
        return GetPassportAuthorizationForm.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ReadFilePart(BaseObject):
    """
    Reads a part of a file from the TDLib file cache and returns read bytes. This method is intended to be used only if the application has no direct access to TDLib's file system, because it is usually slower than a direct read from the file
    
    Params:
        file_id (:class:`int`)
            Identifier of the file. The file must be located in the TDLib file cache
        
        offset (:class:`int`)
            The offset from which to read the file
        
        count (:class:`int`)
            Number of bytes to read. An error will be returned if there are not enough bytes available in the file from the specified position. Pass 0 to read all available data from the specified position
        
    """

    ID: str = Field("readFilePart", alias="@type")
    file_id: int
    offset: int
    count: int

    @staticmethod
    def read(q: dict) -> ReadFilePart:
        return ReadFilePart.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatFilter(BaseObject):
    """
    Represents a filter of user chats
    
    Params:
        title (:class:`str`)
            The title of the filter; 1-12 characters without line feeds
        
        icon_name (:class:`str`)
            The icon name for short filter representation. If non-empty, must be one of "All", "Unread", "Unmuted", "Bots", "Channels", "Groups", "Private", "Custom", "Setup", "Cat", "Crown", "Favorite", "Flower", "Game", "Home", "Love", "Mask", "Party", "Sport", "Study", "Trade", "Travel", "Work". If empty, use getChatFilterDefaultIconName to get default icon name for the filter
        
        pinned_chat_ids (:obj:`list[int]`)
            The chat identifiers of pinned chats in the filtered chat list
        
        included_chat_ids (:obj:`list[int]`)
            The chat identifiers of always included chats in the filtered chat list
        
        excluded_chat_ids (:obj:`list[int]`)
            The chat identifiers of always excluded chats in the filtered chat list
        
        exclude_muted (:class:`bool`)
            True, if muted chats need to be excluded
        
        exclude_read (:class:`bool`)
            True, if read chats need to be excluded
        
        exclude_archived (:class:`bool`)
            True, if archived chats need to be excluded
        
        include_contacts (:class:`bool`)
            True, if contacts need to be included
        
        include_non_contacts (:class:`bool`)
            True, if non-contact users need to be included
        
        include_bots (:class:`bool`)
            True, if bots need to be included
        
        include_groups (:class:`bool`)
            True, if basic groups and supergroups need to be included
        
        include_channels (:class:`bool`)
            True, if channels need to be included
        
    """

    ID: str = Field("chatFilter", alias="@type")
    title: str = Field(..., min_length=1, max_length=12)
    icon_name: str
    pinned_chat_ids: list[int]
    included_chat_ids: list[int]
    excluded_chat_ids: list[int]
    exclude_muted: bool
    exclude_read: bool
    exclude_archived: bool
    include_contacts: bool
    include_non_contacts: bool
    include_bots: bool
    include_groups: bool
    include_channels: bool

    @staticmethod
    def read(q: dict) -> ChatFilter:
        return ChatFilter.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetMessages(BaseObject):
    """
    Returns information about messages. If a message is not found, returns null on the corresponding position of the result
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat the messages belong to
        
        message_ids (:obj:`list[int]`)
            Identifiers of the messages to get
        
    """

    ID: str = Field("getMessages", alias="@type")
    chat_id: int
    message_ids: list[int]

    @staticmethod
    def read(q: dict) -> GetMessages:
        return GetMessages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .file import File
from .minithumbnail import Minithumbnail
from ..base_object import BaseObject


class ProfilePhoto(BaseObject):
    """
    Describes a user profile photo
    
    Params:
        id (:class:`int`)
            Photo identifier; 0 for an empty photo. Can be used to find a photo in a list of user profile photos
        
        small (:class:`File`)
            A small (160x160) user profile photo. The file can be downloaded only before the photo is changed
        
        big (:class:`File`)
            A big (640x640) user profile photo. The file can be downloaded only before the photo is changed
        
        minithumbnail (:class:`Minithumbnail`)
            User profile photo minithumbnail; may be null
        
        has_animation (:class:`bool`)
            True, if the photo has animated variant
        
    """

    ID: str = Field("profilePhoto", alias="@type")
    id: int
    small: File
    big: File
    minithumbnail: typing.Optional[Minithumbnail] = None
    has_animation: bool

    @staticmethod
    def read(q: dict) -> ProfilePhoto:
        return ProfilePhoto.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import MessageSender


class GetChatMember(BaseObject):
    """
    Returns information about a single member of a chat
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        member_id (:class:`MessageSender`)
            Member identifier
        
    """

    ID: str = Field("getChatMember", alias="@type")
    chat_id: int
    member_id: MessageSender

    @staticmethod
    def read(q: dict) -> GetChatMember:
        return GetChatMember.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import SearchMessagesFilter


class SearchSecretMessages(BaseObject):
    """
    Searches for messages in secret chats. Returns the results in reverse chronological order. For optimal performance the number of returned messages is chosen by the library
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat in which to search. Specify 0 to search in all secret chats
        
        query (:class:`str`)
            Query to search for. If empty, searchChatMessages should be used instead
        
        offset (:class:`str`)
            Offset of the first entry to return as received from the previous request; use empty string to get first chunk of results
        
        limit (:class:`int`)
            The maximum number of messages to be returned; up to 100. Fewer messages may be returned than specified by the limit, even if the end of the message history has not been reached
        
        filter_ (:class:`SearchMessagesFilter`)
            A filter for message content in the search results
        
    """

    ID: str = Field("searchSecretMessages", alias="@type")
    chat_id: int
    query: str
    offset: str
    limit: int
    filter_: SearchMessagesFilter = Field(..., alias='filter')

    @staticmethod
    def read(q: dict) -> SearchSecretMessages:
        return SearchSecretMessages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import JsonValue


class SaveApplicationLogEvent(BaseObject):
    """
    Saves application log event on the server. Can be called before authorization
    
    Params:
        type_ (:class:`str`)
            Event type
        
        chat_id (:class:`int`)
            Optional chat identifier, associated with the event
        
        data (:class:`JsonValue`)
            The log event data
        
    """

    ID: str = Field("saveApplicationLogEvent", alias="@type")
    type_: str = Field(..., alias='type')
    chat_id: int
    data: JsonValue

    @staticmethod
    def read(q: dict) -> SaveApplicationLogEvent:
        return SaveApplicationLogEvent.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetChatTitle(BaseObject):
    """
    Changes the chat title. Supported only for basic groups, supergroups and channels. Requires can_change_info administrator right
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        title (:class:`str`)
            New title of the chat; 1-128 characters
        
    """

    ID: str = Field("setChatTitle", alias="@type")
    chat_id: int
    title: str = Field(..., min_length=1, max_length=128)

    @staticmethod
    def read(q: dict) -> SetChatTitle:
        return SetChatTitle.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class PublicChatType(BaseObject):
    """
    Describes a type of public chats
    
    """

    ID: str = Field("publicChatType", alias="@type")


class PublicChatTypeHasUsername(PublicChatType):
    """
    The chat is public, because it has username
    
    """

    ID: str = Field("publicChatTypeHasUsername", alias="@type")

    @staticmethod
    def read(q: dict) -> PublicChatTypeHasUsername:
        return PublicChatTypeHasUsername.construct(**q)


class PublicChatTypeIsLocationBased(PublicChatType):
    """
    The chat is public, because it is a location-based supergroup
    
    """

    ID: str = Field("publicChatTypeIsLocationBased", alias="@type")

    @staticmethod
    def read(q: dict) -> PublicChatTypeIsLocationBased:
        return PublicChatTypeIsLocationBased.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ReplyMarkup


class EditInlineMessageReplyMarkup(BaseObject):
    """
    Edits the reply markup of an inline message sent via a bot; for bots only
    
    Params:
        inline_message_id (:class:`str`)
            Inline message identifier
        
        reply_markup (:class:`ReplyMarkup`)
            The new message reply markup
        
    """

    ID: str = Field("editInlineMessageReplyMarkup", alias="@type")
    inline_message_id: str
    reply_markup: ReplyMarkup

    @staticmethod
    def read(q: dict) -> EditInlineMessageReplyMarkup:
        return EditInlineMessageReplyMarkup.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .call_discard_reason import CallDiscardReason
from .call_protocol import CallProtocol
from .call_server import CallServer
from .error import Error
from ..base_object import BaseObject


class CallState(BaseObject):
    """
    Describes the current call state
    
    """

    ID: str = Field("callState", alias="@type")


class CallStateDiscarded(CallState):
    """
    The call has ended successfully
    
    Params:
        reason (:class:`CallDiscardReason`)
            The reason, why the call has ended
        
        need_rating (:class:`bool`)
            True, if the call rating should be sent to the server
        
        need_debug_information (:class:`bool`)
            True, if the call debug information should be sent to the server
        
    """

    ID: str = Field("callStateDiscarded", alias="@type")
    reason: CallDiscardReason
    need_rating: bool
    need_debug_information: bool

    @staticmethod
    def read(q: dict) -> CallStateDiscarded:
        return CallStateDiscarded.construct(**q)


class CallStateError(CallState):
    """
    The call has ended with an error
    
    Params:
        error (:class:`Error`)
            Error. An error with the code 4005000 will be returned if an outgoing call is missed because of an expired timeout
        
    """

    ID: str = Field("callStateError", alias="@type")
    error: Error

    @staticmethod
    def read(q: dict) -> CallStateError:
        return CallStateError.construct(**q)


class CallStateExchangingKeys(CallState):
    """
    The call has been answered and encryption keys are being exchanged
    
    """

    ID: str = Field("callStateExchangingKeys", alias="@type")

    @staticmethod
    def read(q: dict) -> CallStateExchangingKeys:
        return CallStateExchangingKeys.construct(**q)


class CallStateHangingUp(CallState):
    """
    The call is hanging up after discardCall has been called
    
    """

    ID: str = Field("callStateHangingUp", alias="@type")

    @staticmethod
    def read(q: dict) -> CallStateHangingUp:
        return CallStateHangingUp.construct(**q)


class CallStatePending(CallState):
    """
    The call is pending, waiting to be accepted by a user
    
    Params:
        is_created (:class:`bool`)
            True, if the call has already been created by the server
        
        is_received (:class:`bool`)
            True, if the call has already been received by the other party
        
    """

    ID: str = Field("callStatePending", alias="@type")
    is_created: bool
    is_received: bool

    @staticmethod
    def read(q: dict) -> CallStatePending:
        return CallStatePending.construct(**q)


class CallStateReady(CallState):
    """
    The call is ready to use
    
    Params:
        protocol (:class:`CallProtocol`)
            Call protocols supported by the peer
        
        servers (:obj:`list[CallServer]`)
            List of available call servers
        
        config (:class:`str`)
            A JSON-encoded call config
        
        encryption_key (:class:`str`)
            Call encryption key
        
        emojis (:obj:`list[str]`)
            Encryption key emojis fingerprint
        
        allow_p2p (:class:`bool`)
            True, if peer-to-peer connection is allowed by users privacy settings
        
    """

    ID: str = Field("callStateReady", alias="@type")
    protocol: CallProtocol
    servers: list[CallServer]
    config: str
    encryption_key: str
    emojis: list[str]
    allow_p2p: bool

    @staticmethod
    def read(q: dict) -> CallStateReady:
        return CallStateReady.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SearchChatRecentLocationMessages(BaseObject):
    """
    Returns information about the recent locations of chat members that were sent to the chat. Returns up to 1 location message per user
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        limit (:class:`int`)
            The maximum number of messages to be returned
        
    """

    ID: str = Field("searchChatRecentLocationMessages", alias="@type")
    chat_id: int
    limit: int

    @staticmethod
    def read(q: dict) -> SearchChatRecentLocationMessages:
        return SearchChatRecentLocationMessages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from ..base_object import BaseObject


class RegisterUser(BaseObject):
    """
    Finishes user registration. Works only when the current authorization state is authorizationStateWaitRegistration
    
    Params:
        first_name (:class:`str`)
            The first name of the user; 1-64 characters
        
        last_name (:class:`str`)
            The last name of the user; 0-64 characters
        
    """

    ID: str = Field("registerUser", alias="@type")
    first_name: str = Field(..., min_length=1, max_length=64)
    last_name: typing.Optional[str] = Field(None, max_length=64)

    @staticmethod
    def read(q: dict) -> RegisterUser:
        return RegisterUser.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import UserPrivacySetting


class GetUserPrivacySettingRules(BaseObject):
    """
    Returns the current privacy settings
    
    Params:
        setting (:class:`UserPrivacySetting`)
            The privacy setting
        
    """

    ID: str = Field("getUserPrivacySettingRules", alias="@type")
    setting: UserPrivacySetting

    @staticmethod
    def read(q: dict) -> GetUserPrivacySettingRules:
        return GetUserPrivacySettingRules.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetLoginUrlInfo(BaseObject):
    """
    Returns information about a button of type inlineKeyboardButtonTypeLoginUrl. The method needs to be called when the user presses the button
    
    Params:
        chat_id (:class:`int`)
            Chat identifier of the message with the button
        
        message_id (:class:`int`)
            Message identifier of the message with the button
        
        button_id (:class:`int`)
            Button identifier
        
    """

    ID: str = Field("getLoginUrlInfo", alias="@type")
    chat_id: int
    message_id: int
    button_id: int

    @staticmethod
    def read(q: dict) -> GetLoginUrlInfo:
        return GetLoginUrlInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ResendChangePhoneNumberCode(BaseObject):
    """
    Re-sends the authentication code sent to confirm a new phone number for the user. Works only if the previously received authenticationCodeInfo next_code_type was not null and the server-specified timeout has passed
    
    """

    ID: str = Field("resendChangePhoneNumberCode", alias="@type")

    @staticmethod
    def read(q: dict) -> ResendChangePhoneNumberCode:
        return ResendChangePhoneNumberCode.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class JsonValue(BaseObject):
    """
    Represents a JSON value
    
    """

    ID: str = Field("jsonValue", alias="@type")


class JsonValueArray(JsonValue):
    """
    Represents a JSON array
    
    Params:
        values (:obj:`list[JsonValue]`)
            The list of array elements
        
    """

    ID: str = Field("jsonValueArray", alias="@type")
    values: list[JsonValue]

    @staticmethod
    def read(q: dict) -> JsonValueArray:
        return JsonValueArray.construct(**q)


class JsonValueBoolean(JsonValue):
    """
    Represents a boolean JSON value
    
    Params:
        value (:class:`bool`)
            The value
        
    """

    ID: str = Field("jsonValueBoolean", alias="@type")
    value: bool

    @staticmethod
    def read(q: dict) -> JsonValueBoolean:
        return JsonValueBoolean.construct(**q)


class JsonValueNull(JsonValue):
    """
    Represents a null JSON value
    
    """

    ID: str = Field("jsonValueNull", alias="@type")

    @staticmethod
    def read(q: dict) -> JsonValueNull:
        return JsonValueNull.construct(**q)


class JsonValueNumber(JsonValue):
    """
    Represents a numeric JSON value
    
    Params:
        value (:class:`float`)
            The value
        
    """

    ID: str = Field("jsonValueNumber", alias="@type")
    value: float

    @staticmethod
    def read(q: dict) -> JsonValueNumber:
        return JsonValueNumber.construct(**q)


class JsonValueObject(JsonValue):
    """
    Represents a JSON object
    
    Params:
        members (:obj:`list[JsonObjectMember]`)
            The list of object members
        
    """

    ID: str = Field("jsonValueObject", alias="@type")
    members: list[JsonObjectMember]

    @staticmethod
    def read(q: dict) -> JsonValueObject:
        return JsonValueObject.construct(**q)


class JsonValueString(JsonValue):
    """
    Represents a string JSON value
    
    Params:
        value (:class:`str`)
            The value
        
    """

    ID: str = Field("jsonValueString", alias="@type")
    value: str

    @staticmethod
    def read(q: dict) -> JsonValueString:
        return JsonValueString.construct(**q)


class JsonObjectMember(BaseObject):
    """
    Represents one member of a JSON object
    
    Params:
        key (:class:`str`)
            Member's key
        
        value (:class:`JsonValue`)
            Member's value
        
    """

    ID: str = Field("jsonObjectMember", alias="@type")
    key: str
    value: JsonValue

    @staticmethod
    def read(q: dict) -> JsonObjectMember:
        return JsonObjectMember.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .bot_command import BotCommand
from ..base_object import BaseObject


class BotCommands(BaseObject):
    """
    Contains a list of bot commands
    
    Params:
        bot_user_id (:class:`int`)
            Bot's user identifier
        
        commands (:obj:`list[BotCommand]`)
            List of bot commands
        
    """

    ID: str = Field("botCommands", alias="@type")
    bot_user_id: int
    commands: list[BotCommand]

    @staticmethod
    def read(q: dict) -> BotCommands:
        return BotCommands.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetUserFullInfo(BaseObject):
    """
    Returns full information about a user by their identifier
    
    Params:
        user_id (:class:`int`)
            User identifier
        
    """

    ID: str = Field("getUserFullInfo", alias="@type")
    user_id: int

    @staticmethod
    def read(q: dict) -> GetUserFullInfo:
        return GetUserFullInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GroupCallVideoSourceGroup(BaseObject):
    """
    Describes a group of video synchronization source identifiers
    
    Params:
        semantics (:class:`str`)
            The semantics of sources, one of "SIM" or "FID"
        
        source_ids (:obj:`list[int]`)
            The list of synchronization source identifiers
        
    """

    ID: str = Field("groupCallVideoSourceGroup", alias="@type")
    semantics: str
    source_ids: list[int]

    @staticmethod
    def read(q: dict) -> GroupCallVideoSourceGroup:
        return GroupCallVideoSourceGroup.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputFile


class AddSavedAnimation(BaseObject):
    """
    Manually adds a new animation to the list of saved animations. The new animation is added to the beginning of the list. If the animation was already in the list, it is removed first. Only non-secret video animations with MIME type "video/mp4" can be added to the list
    
    Params:
        animation (:class:`InputFile`)
            The animation file to be added. Only animations known to the server (i.e. successfully sent via a message) can be added to the list
        
    """

    ID: str = Field("addSavedAnimation", alias="@type")
    animation: InputFile

    @staticmethod
    def read(q: dict) -> AddSavedAnimation:
        return AddSavedAnimation.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .recommended_chat_filter import RecommendedChatFilter
from ..base_object import BaseObject


class RecommendedChatFilters(BaseObject):
    """
    Contains a list of recommended chat filters
    
    Params:
        chat_filters (:obj:`list[RecommendedChatFilter]`)
            List of recommended chat filters
        
    """

    ID: str = Field("recommendedChatFilters", alias="@type")
    chat_filters: list[RecommendedChatFilter]

    @staticmethod
    def read(q: dict) -> RecommendedChatFilters:
        return RecommendedChatFilters.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class MessageFileType(BaseObject):
    """
    Contains information about a file with messages exported from another app
    
    """

    ID: str = Field("messageFileType", alias="@type")


class MessageFileTypeGroup(MessageFileType):
    """
    The messages was exported from a group chat
    
    Params:
        title (:class:`str`)
            Title of the group chat; may be empty if unrecognized
        
    """

    ID: str = Field("messageFileTypeGroup", alias="@type")
    title: str

    @staticmethod
    def read(q: dict) -> MessageFileTypeGroup:
        return MessageFileTypeGroup.construct(**q)


class MessageFileTypePrivate(MessageFileType):
    """
    The messages was exported from a private chat
    
    Params:
        name (:class:`str`)
            Name of the other party; may be empty if unrecognized
        
    """

    ID: str = Field("messageFileTypePrivate", alias="@type")
    name: str

    @staticmethod
    def read(q: dict) -> MessageFileTypePrivate:
        return MessageFileTypePrivate.construct(**q)


class MessageFileTypeUnknown(MessageFileType):
    """
    The messages was exported from a chat of unknown type
    
    """

    ID: str = Field("messageFileTypeUnknown", alias="@type")

    @staticmethod
    def read(q: dict) -> MessageFileTypeUnknown:
        return MessageFileTypeUnknown.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetNetworkStatistics(BaseObject):
    """
    Returns network data usage statistics. Can be called before authorization
    
    Params:
        only_current (:class:`bool`)
            If true, returns only data for the current library launch
        
    """

    ID: str = Field("getNetworkStatistics", alias="@type")
    only_current: bool

    @staticmethod
    def read(q: dict) -> GetNetworkStatistics:
        return GetNetworkStatistics.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import MessageSendOptions


class ForwardMessages(BaseObject):
    """
    Forwards previously sent messages. Returns the forwarded messages in the same order as the message identifiers passed in message_ids. If a message can't be forwarded, null will be returned instead of the message
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat to which to forward messages
        
        from_chat_id (:class:`int`)
            Identifier of the chat from which to forward messages
        
        message_ids (:obj:`list[int]`)
            Identifiers of the messages to forward. Message identifiers must be in a strictly increasing order. At most 100 messages can be forwarded simultaneously
        
        options (:class:`MessageSendOptions`)
            Options to be used to send the messages
        
        send_copy (:class:`bool`)
            True, if content of the messages needs to be copied without links to the original messages. Always true if the messages are forwarded to a secret chat
        
        remove_caption (:class:`bool`)
            True, if media caption of message copies needs to be removed. Ignored if send_copy is false
        
    """

    ID: str = Field("forwardMessages", alias="@type")
    chat_id: int
    from_chat_id: int
    message_ids: list[int]
    options: MessageSendOptions
    send_copy: bool
    remove_caption: bool

    @staticmethod
    def read(q: dict) -> ForwardMessages:
        return ForwardMessages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import TextParseMode


class ParseTextEntities(BaseObject):
    """
    Parses Bold, Italic, Underline, Strikethrough, Code, Pre, PreCode, TextUrl and MentionName entities contained in the text. Can be called synchronously
    
    Params:
        text (:class:`str`)
            The text to parse
        
        parse_mode (:class:`TextParseMode`)
            Text parse mode
        
    """

    ID: str = Field("parseTextEntities", alias="@type")
    text: str
    parse_mode: TextParseMode

    @staticmethod
    def read(q: dict) -> ParseTextEntities:
        return ParseTextEntities.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CheckStickerSetNameResult(BaseObject):
    """
    Represents result of checking whether a name can be used for a new sticker set
    
    """

    ID: str = Field("checkStickerSetNameResult", alias="@type")


class CheckStickerSetNameResultNameInvalid(CheckStickerSetNameResult):
    """
    The name is invalid
    
    """

    ID: str = Field("checkStickerSetNameResultNameInvalid", alias="@type")

    @staticmethod
    def read(q: dict) -> CheckStickerSetNameResultNameInvalid:
        return CheckStickerSetNameResultNameInvalid.construct(**q)


class CheckStickerSetNameResultNameOccupied(CheckStickerSetNameResult):
    """
    The name is occupied
    
    """

    ID: str = Field("checkStickerSetNameResultNameOccupied", alias="@type")

    @staticmethod
    def read(q: dict) -> CheckStickerSetNameResultNameOccupied:
        return CheckStickerSetNameResultNameOccupied.construct(**q)


class CheckStickerSetNameResultOk(CheckStickerSetNameResult):
    """
    The name can be set
    
    """

    ID: str = Field("checkStickerSetNameResultOk", alias="@type")

    @staticmethod
    def read(q: dict) -> CheckStickerSetNameResultOk:
        return CheckStickerSetNameResultOk.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputFile


class GetStickerEmojis(BaseObject):
    """
    Returns emoji corresponding to a sticker. The list is only for informational purposes, because a sticker is always sent with a fixed emoji from the corresponding Sticker object
    
    Params:
        sticker (:class:`InputFile`)
            Sticker file identifier
        
    """

    ID: str = Field("getStickerEmojis", alias="@type")
    sticker: InputFile

    @staticmethod
    def read(q: dict) -> GetStickerEmojis:
        return GetStickerEmojis.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class EditChatInviteLink(BaseObject):
    """
    Edits a non-primary invite link for a chat. Available for basic groups, supergroups, and channels. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        invite_link (:class:`str`)
            Invite link to be edited
        
        expire_date (:class:`int`)
            Point in time (Unix timestamp) when the link will expire; pass 0 if never
        
        member_limit (:class:`int`)
            The maximum number of chat members that can join the chat by the link simultaneously; 0-99999; pass 0 if not limited
        
    """

    ID: str = Field("editChatInviteLink", alias="@type")
    chat_id: int
    invite_link: str
    expire_date: int
    member_limit: int

    @staticmethod
    def read(q: dict) -> EditChatInviteLink:
        return EditChatInviteLink.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CreateNewSecretChat(BaseObject):
    """
    Creates a new secret chat. Returns the newly created chat
    
    Params:
        user_id (:class:`int`)
            Identifier of the target user
        
    """

    ID: str = Field("createNewSecretChat", alias="@type")
    user_id: int

    @staticmethod
    def read(q: dict) -> CreateNewSecretChat:
        return CreateNewSecretChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputPassportElementError


class SetPassportElementErrors(BaseObject):
    """
    Informs the user that some of the elements in their Telegram Passport contain errors; for bots only. The user will not be able to resend the elements, until the errors are fixed
    
    Params:
        user_id (:class:`int`)
            User identifier
        
        errors (:obj:`list[InputPassportElementError]`)
            The errors
        
    """

    ID: str = Field("setPassportElementErrors", alias="@type")
    user_id: int
    errors: list[InputPassportElementError]

    @staticmethod
    def read(q: dict) -> SetPassportElementErrors:
        return SetPassportElementErrors.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class InviteGroupCallParticipants(BaseObject):
    """
    Invites users to an active group call. Sends a service message of type messageInviteToGroupCall for voice chats
    
    Params:
        group_call_id (:class:`int`)
            Group call identifier
        
        user_ids (:obj:`list[int]`)
            User identifiers. At most 10 users can be invited simultaneously
        
    """

    ID: str = Field("inviteGroupCallParticipants", alias="@type")
    group_call_id: int
    user_ids: list[int]

    @staticmethod
    def read(q: dict) -> InviteGroupCallParticipants:
        return InviteGroupCallParticipants.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetLogTagVerbosityLevel(BaseObject):
    """
    Returns current verbosity level for a specified TDLib internal log tag. Can be called synchronously
    
    Params:
        tag (:class:`str`)
            Logging tag to change verbosity level
        
    """

    ID: str = Field("getLogTagVerbosityLevel", alias="@type")
    tag: str

    @staticmethod
    def read(q: dict) -> GetLogTagVerbosityLevel:
        return GetLogTagVerbosityLevel.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class MessageSendingState(BaseObject):
    """
    Contains information about the sending state of the message
    
    """

    ID: str = Field("messageSendingState", alias="@type")


class MessageSendingStateFailed(MessageSendingState):
    """
    The message failed to be sent
    
    Params:
        error_code (:class:`int`)
            An error code; 0 if unknown
        
        error_message (:class:`str`)
            Error message
        
        can_retry (:class:`bool`)
            True, if the message can be re-sent
        
        retry_after (:class:`float`)
            Time left before the message can be re-sent, in seconds. No update is sent when this field changes
        
    """

    ID: str = Field("messageSendingStateFailed", alias="@type")
    error_code: int
    error_message: str
    can_retry: bool
    retry_after: float

    @staticmethod
    def read(q: dict) -> MessageSendingStateFailed:
        return MessageSendingStateFailed.construct(**q)


class MessageSendingStatePending(MessageSendingState):
    """
    The message is being sent now, but has not yet been delivered to the server
    
    """

    ID: str = Field("messageSendingStatePending", alias="@type")

    @staticmethod
    def read(q: dict) -> MessageSendingStatePending:
        return MessageSendingStatePending.construct(**q)
